---
title: L'impact environnemental du numérique
description: Que savons-nous de l'impact du numérique ? Son impact est-il « virtuel » et « dématérialisé » comme on aime à le prétendre ? Nous vous proposons une série d'articles qui expliquent d'abord le lien entre le numérique et son environnement, puis les solutions que nous proposons chez RésiLien
date: 2022-01-26
---

# L'impact environnemental du numérique

Il existe aujourd'hui en France un consensus pour admettre que les activités humaines ont une influence sur leur environnement. Nous savons que les déchets plastiques qui sont jetés dans la nature se décomposent et se retrouvent sous forme de nano-particules dans l'air et dans les poissons que l'on pêche. Nous savons que les trajets en avion émettent une quantité impressionnante de gaz à effet de serre (GES) et contribuent au réchauffement climatique.

Mais que savons-nous de l'impact du numérique ? Son impact est-il « virtuel » et « dématérialisé » comme on aime à le prétendre ? Nous vous proposons une série d'articles qui expliquent d'abord le lien entre le numérique et son environnement, puis les solutions que nous proposons chez RésiLien.

## Le réchauffement climatique

Tout d'abord, nous proposons de débuter cet article par un rappel sur le réchauffement climatique. L'enjeu autour de celui-ci est critique car plus le réchauffement est important moins le comportement de notre planète est prédictible. Il est avéré que la montée des eaux s'accélère, que les feux de forêts s'intensifient et que les récoltes agricoles sont moins abondantes à cause des sécheresses plus fréquentes pour citer quelques unes des multiples conséquences [^impact-rechauffement-france][^wwf-impact-rechauffement]. L'habitabilité de la planète pour les humains devient de plus en plus difficile et nous avons besoin de nous adapter à ces changements de plus en plus vite.

L'UNEP, un programme des Nations Unies, a publié un rapport en décembre 2020 illustrant plusieurs scénarios de réchauffement climatique en fonction de la quantité d'émission de gaz à effet de serre. Il ne s'agit pas du premier rapport de ce type et certainement pas du dernier mais il a le mérite de proposer un beau graphique récapitulatif. Avant de lire le graphique, nous précisons que le CO<sub>2</sub>e est une unité de mesure qui permet de mesurer l'impact de l'ensemble des gaz à effet de serre (par exemple le méthane, le dioxyde de carbone et l'eau) comme s'il ne s'agissait que de CO<sub>2</sub> (le dioxyde de carbone). En continuant nos activités humaines avec les politiques actuelles, les scientifiques prédisent que nous émettrons environ 60 GtCO<sub>2</sub>e en 2030. Ce qui correspondrait à un réchauffement climatique global largement au dessus de 2°C.

D'après les accords de Paris de la COP21 en 2015, les pays se sont engagés à conserver le réchauffement global à « bien en dessous » de 2°C et à « mener des efforts encore plus poussés pour limiter l’augmentation de la température à 1,5°C au-dessus des niveaux pré-industriels »[^accords-de-paris]. Nous sommes aujourd'hui encore loin des objectifs annoncés et il est très improbable que nous puissions respecter l'objectif de +1,5°C.

![Écarts d’émissions entre les trajectoires actuelles, les engagements actuels et les scénarios à +1,5°C et + 2°C. Source : UNEP, Emissions Gap Report 2020](graphique_rechauffement.png)[^emissions-gap-report]

## La part du numérique dans le réchauffement climatique

Après avoir rappelé les enjeux et les ordres de grandeur autour du réchauffement climatique, quelle est la part liée au numérique ?

Le Shift Project, un think tank spécialisé sur la transition énergétique, a publié un rapport en 2018 sur la part du numérique. D'après ce rapport, en 2019 le numérique représentait 4% des émissions de gaz à effet de serre (GES) et avec une croissance de 8% par an, sans changement de comportement, celui-ci représentera environ 8% des émissions de GES en 2025. En comparaison, en 2019 le secteur des transports représentait 31% des émissions de GES, l'industrie de l'énergie 10% et les déchets 3% [^notre-environnement-ges].

Les transports représentent certes la plus grande part des émissions, mais le numérique tend à prendre une part de plus en plus importante. Ce rapport du Shift Project a mis un coup de projecteur sur l'impact du numérique afin que l'on considère aussi à prendre des mesures pour ce secteur.

![Évolution 2013-2025 de la part du numérique dans les émissions de GES mondiales. Source : (The Shift Project, 2018)](part_numerique_ges.png)[^the-shift-project-2018]

## L'impact du numérique plus en détail

Pendant un certain temps, beaucoup de spécialistes se sont concentrés sur la consommation énergétique du numérique, représentée par les centres de données notamment. Pourtant il je s'agit que de la partie immergée de l'iceberg.

Aujourd'hui l'avis des experts a changé pour admettre que la plus grande pollution en ressources abiotiques[^abiotique], en émission de GES et en eau se produit au moment de la fabrication du matériel numérique. Il est à noter qu'en France, du fait que la majorité de l'électricité produite provient de centrales nucléaires, peu d'émissions en GES sont comptabilisés pour la consommation énergétique. Le tableau ci-dessous produit par GreenIT.fr en 2021 montre que les terminaux des utilisateurs représentent la part la plus importante de la pollution sur les quatre critères : consommation d'énergie, émission de GES, consommation en eau et consommation de ressources


![« Impacts environnementaux du numérique en France » - Collectif d’experts - 17 janvier 2021. Source : GreenIT.fr](impact_numerique_france_2020.png)[^impact-environnementaux-numerique-greenit]

*(1) (voir tableau) Cet indicateur de contribution à l’épuisement des ressources abiotiques ne prend en compte que les ressources« matière ». L’énergie fossile, qui est aussi une ressource abiotique, n’est pas prise en compte. En revanche, le pétrole, s’il est utilisé pour fabriquer du plastique, est par exemple pris en compte.*

En France, la priorité n'est donc pas de réduire la consommation d'énergie des appareils, même si c'est aussi un levier d'action, mais plutôt de ralentir le renouvellement du parc informatique.

## Conclusion

Certes les secteurs des transports et de l'agriculture représentent la plus grande part des émissions de gaz à effet de serre (GES), mais le numérique est de plus en plus utilisé et prend une part de plus en plus importante. En France, de part un mix énergétique comprenant en majorité l'énergie d'origine nucléaire, les émissions de GES sont plus faibles que pour d'autres pays.

Nous tenons à vous faire remarquer que dans cet article, nous n'avons considéré que les émissions de GES qui agissent directement sur le réchauffement climatique. Nous n'avons pas détaillé la pollution liée directement à l'exploitation de mines et à la fabrication de cartes électroniques. Le sujet de l'impact environnemental du numérique est encore à ses débuts et nous n'avons pas connaissance de tous les détails.

En revanche une chose est sûre, le numérique, de même que toutes les autres activités humaines, doit s'adapter pour réduire sa participation au réchauffement climatique et nous permettre de conserver l'habitabilité de la planète pour les humains.

Chez RésiLien nous expérimentons des solutions afin de réduire l'empreinte du numérique sur l'environnement et rendre le numérique plus résilient. Nous détaillerons nos travaux dans de prochains articles.

[^accords-de-paris]: L'accord de Paris. Accueil | economie.gouv.fr [en ligne]. [sans date] [consulté le 20 janvier 2022]. Disponible sur : https://www.economie.gouv.fr/laccord-de-paris
[^emissions-gap-report]: Emissions Gap Report 2020. UNEP - UN Environment Programme [en ligne]. [sans date] [consulté le 20 janvier 2022]. Disponible sur : https://www.unep.org/emissions-gap-report-2020
[^impact-rechauffement-france]: Impacts du changement climatique : Santé et Société. Ministère de la Transition écologique [en ligne]. [sans date] [consulté le 20 janvier 2022]. Disponible sur : https://www.ecologie.gouv.fr/impacts-du-changement-climatique-sante-et-societe
[^wwf-impact-rechauffement]: Les conséquences du réchauffement climatique - Urgence Climat. WWF | Urgence Climat [en ligne]. [sans date] [consulté le 20 janvier 2022]. Disponible sur : https://agir.wwf.fr/urgence-climat/consequences/
[^notre-environnement-ges]: Les émissions de gaz à effet de serre du secteur des transports. notre-environnement.gouv.fr [en ligne]. [sans date] [consulté le 20 janvier 2022]. Disponible sur : https://www.notre-environnement.gouv.fr/rapport-sur-l-etat-de-l-environnement/themes-ree/defis-environnementaux/changement-climatique/emissions-de-gaz-a-effet-de-serre/article/les-emissions-de-gaz-a-effet-de-serre-du-secteur-des-transports
[^abiotique]:  abiotique :  ressources naturelles non renouvelables (= minerais, énergie fossile)
[^impact-environnementaux-numerique-greenit]: « Impacts environnementaux du numérique en France » - Collectif d’experts - 17 janvier 2021. Source : GreenIT.fr
[^the-shift-project-2018]: Évolution 2013-2025 de la part du numérique dans les émissions de GES mondiales. Source : (The Shift Project, 2018)
